Checkout
========

General
-------

* The kind of checkout is choosable.

    Only as guest:
       Shop customer have no possibility to login and are redirected directly
       to the checkout page.

    Only logged in:
       Shop customer have to login or register at the beginning of the checkout
       process.

    As guest and logged in:
       Shop customer can choose at the beginning of the checkout process whether
       they login, register or checkout without registration/login

Further infomation
------------------
* :doc:`../developer/customer`
* :doc:`addresses`